import { ElementStyles } from '@microsoft/fast-element';
import type { AuthRoutes } from '../routes/types';
/**
 * @public
 * Could be expanded to allow field ViewTemplates.
 */
export type FieldConfig = {
    label: string;
    /**
     * @privateRemarks
     * Added for now to apply defaults, but I'm not convinced we should do this. Could be made reactive after upgrade.
     */
    value?: any;
    /**
     * @remarks
     * We expect fields to be required by default, but you can override to make them optional. Organisation for example.
     */
    required?: boolean;
    /**
     * @remarks
     * A regular expression the control's value should match. Please note the email field has its own built in pattern.
     */
    pattern?: string;
    /**
     * @remarks
     * Used in conjunction with the pattern to explain the conditions.
     */
    title?: string;
};
/**
 * @public
 * @privateRemarks
 * Using null to exclude the organisation field rather than boolean, as it affords cleaner value lookups in the templates.
 */
export type FieldConfigMap = {
    organisation: FieldConfig | null;
    username: FieldConfig;
    email: FieldConfig;
    password: FieldConfig;
};
/**
 * @public
 */
export type SSOConfig = {
    /**
     * Optionally toggle the SSO journey on/off by default.
     */
    toggled?: boolean;
    /**
     * The identity providers path under the current host.
     *
     * @example
     * ```ts
     * identityProvidersPath: 'sso/list'
     * ```
     */
    identityProvidersPath: string;
};
/**
 * AuthConfig DI interface.
 *
 * @public
 */
export interface AuthConfig {
    /**
     * Logo styles.
     *
     * @remarks
     * Providing `null` will hide the logo. Use content: url(...); to set source.
     *
     * @example Setting a custom logo
     * ```ts
     * logo: css`
     *     content: url(${customLogoImport});
     * `,
     * ```
     */
    logo: ElementStyles | null;
    /**
     * Background styles.
     *
     * @remarks
     * See {@link https://developer.mozilla.org/en-US/docs/Web/CSS/background} for more information.
     *
     * @example Setting a custom background image
     * ```ts
     * background: css`
     *     :host {
     *         background-image: url(${customBGImport});
     *     }
     * `,
     * ```
     */
    background: ElementStyles;
    /**
     * Background video.
     *
     * @remarks
     * Overlays any background image if set. Defaults to `null`.
     */
    backgroundVideo: {
        src: string;
        type: 'video/ogg' | 'video/mp4' | 'video/webm';
    } | null;
    /**
     * Omit any of the internal routes except 'login' and 'not-found'.
     *
     * @remarks
     * Routes specified here will not be configured nor will any internal cross-links to them be displayed.
     *
     * @example
     * ```ts
     * omitRoutes: ['request-account'],
     * ```
     */
    omitRoutes: Exclude<AuthRoutes, 'login' | 'not-found'>[];
    /**
     * Map of configuration for each of the primary form fields.
     *
     * @remarks
     * Use to drive inclusion / exclusion, tailor labels etc.
     */
    fields: FieldConfigMap;
    /**
     * The `path` of the micro frontend as defined in the parent / host route.
     *
     * @remarks
     * Used to help resolve internal route links. Defaults to an empty string.
     */
    hostPath: string;
    /**
     * The forgot password return URL which is used in the email template.
     */
    forgotPasswordReturnUrl: string;
    /**
     * Omit certain return URLs which the session service may have captured.
     *
     * @example
     * ```ts
     * omitRedirectUrls: ['/not-found'],
     * ```
     */
    omitRedirectUrls: string[];
    /**
     * @remarks
     * Called after a successful login and should be overridden by host. User.lastPath() can be used to trump static
     * values when required.
     */
    postLoginRedirect: () => void;
    /**
     * @remarks
     * Called after a successful logout. Routes to back to the login form by default.
     */
    postLogoutRedirect: () => void;
    /**
     * SSO configuration.
     *
     * @remarks
     * Providing `null` excludes the SSO journey option completely.
     */
    sso: SSOConfig | null;
    /**
     * Display arbitrary version information.
     *
     * @remarks
     * Applications may choose to set this to display their Application release version on the login form.
     *
     * @example
     * ```ts
     * versionInformation: 'Version 3.0.0',
     * ```
     */
    versionInformation?: string;
    /**
     * Feedback delay.
     *
     * @remarks
     * The amount of seconds to display user feedback messages, such as "check your inbox" etc. Defaults to 3 seconds.
     */
    feedbackDelay?: number;
}
/**
 * Default AuthConfig DI implementation.
 * @public
 */
export declare const defaultAuthConfig: AuthConfig;
/**
 * AuthConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const AuthConfig: import("@microsoft/fast-foundation").InterfaceSymbol<AuthConfig>;
/**
 * Configure the auth micro frontend settings.
 *
 * @remarks
 * This is primarily for general settings, rather than re-defining the element, static templating / style changes.
 *
 * @param config - A partial AuthConfig.
 *
 * @example Configuring auth on lazy load
 * ```ts
 * title: 'Authenticate',
 * name: 'auth',
 * path: 'auth',
 * element: async () => {
 *   const { configure, Auth } = await import('@genesislcap/foundation-auth');
 *   configure({
 *     hostPath: 'auth',
 *     omitRoutes: ['request-account'],
 *     logo: myCompanyLogo,
 *     background: myAuthBG,
 *     postLoginRedirect: () => {
 *       // You could inspect the user here and route them based on various conditions.
 *       Route.path.push('dashboard');
 *     },
 *   });
 *   return Auth;
 * },
 * layout: authLayout,
 * settings: { public: true },
 * childRouters: true,
 * ```
 *
 * @public
 * @privateRemarks
 * We can tailor the spreading logic after we put it to use. Keeping it simple for now.
 */
export declare function configure(config: Partial<AuthConfig>): void;
//# sourceMappingURL=config.d.ts.map