import { css } from '@microsoft/fast-element';
import { DI, Registration } from '@microsoft/fast-foundation';
import defaultBackgroundSrc from '../assets/bg.jpg';
import defaultLogoSrc from '../assets/genesis-logo-light.svg';
import { getRoutePath, navigateTo } from '../routes/utils';
/**
 * Default AuthConfig DI implementation.
 * @public
 */
export const defaultAuthConfig = {
    logo: css `
    content: url(${defaultLogoSrc});
  `,
    background: css `
    :host {
      background-image: url(${defaultBackgroundSrc});
    }
  `,
    backgroundVideo: null,
    omitRoutes: [],
    fields: {
        organisation: null,
        username: {
            label: 'Username',
            pattern: '^[a-zA-Z0-9.@_\\-]*$',
            title: 'Letters, numbers, and limited special characters @ _ - .',
        },
        email: {
            label: 'Email Address',
        },
        password: {
            label: 'Password',
        },
    },
    hostPath: '',
    forgotPasswordReturnUrl: `${location.protocol}//${location.host}/${getRoutePath('reset-password')}`,
    omitRedirectUrls: ['/not-found', '/not-permitted'],
    postLoginRedirect: () => navigateTo('protected'),
    postLogoutRedirect: () => navigateTo('/'),
    sso: {
        identityProvidersPath: 'gwf/sso/list',
    },
    feedbackDelay: 3000,
};
/**
 * AuthConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export const AuthConfig = DI.createInterface((x) => x.instance(defaultAuthConfig));
/**
 * Configure the auth micro frontend settings.
 *
 * @remarks
 * This is primarily for general settings, rather than re-defining the element, static templating / style changes.
 *
 * @param config - A partial AuthConfig.
 *
 * @example Configuring auth on lazy load
 * ```ts
 * title: 'Authenticate',
 * name: 'auth',
 * path: 'auth',
 * element: async () => {
 *   const { configure, Auth } = await import('@genesislcap/foundation-auth');
 *   configure({
 *     hostPath: 'auth',
 *     omitRoutes: ['request-account'],
 *     logo: myCompanyLogo,
 *     background: myAuthBG,
 *     postLoginRedirect: () => {
 *       // You could inspect the user here and route them based on various conditions.
 *       Route.path.push('dashboard');
 *     },
 *   });
 *   return Auth;
 * },
 * layout: authLayout,
 * settings: { public: true },
 * childRouters: true,
 * ```
 *
 * @public
 * @privateRemarks
 * We can tailor the spreading logic after we put it to use. Keeping it simple for now.
 */
export function configure(config) {
    DI.getOrCreateDOMContainer().register(Registration.instance(AuthConfig, Object.assign(Object.assign({}, defaultAuthConfig), config)));
}
